system_template = """
Create a plan to fulfill the given instruction. 
The plan should be broken down into clear, logical steps that detail how to accomplish the task. 
Consider all necessary user interactions, system processes, and validations, 
and ensure that the steps are in a logical sequence that corresponds to the given instruction.
Also, don't generate redundant steps in the plan.
"""

human_template = """
Instruction: Create a system that can analyze the user
Let’s think step by step.
1. Generate question to understand the personality of the user by AI
2. Show the question to the user
2. Get answer from the user for the asked question
3. Analyze user's answer by AI.
4. Show the analyze to the user.

Instruction: Create a translator which translates to any language
Let’s think step by step.
1. Get output language from the user 
2. Get source text which will be translated from the user
4. If all the inputs are filled, use AI to translate text to output language
5. If translated text is ready, return it to the user

Instruction: Generate a math teacher which can solve a multiple-choice math problem given the choices
Let’s think step by step.
1. Get question from the user
2. Get choices from the user
3. If all the inputs are filled, use AI to generate a solution for that question
4. If solution is ready, use AI to generate multiple choice from the solution.
5. If the choice is ready, return it to the user

Instruction: Generate a system that can generate tweet from hashtags and give a score for the tweet.
Let’s think step by step.
1. Get hashtags from the user
2. If hashtags are filled, use ai to create tweet.
3. If tweet is created, use AI to generate a score.
4. If score is created, return tweet and score to the user.

Instruction: Create a platform which lets the user select a lecture and then show topics for that lecture 
then give a question to the user. After user gives his/her answer, it gives a score for the answer and give explanation.
Let’s think step by step.
1. Use AI to generate lectures
2. Get lecture from the user among those generated by AI.
3. After user selects a lecture, generate topics releated to that lecture.
4. Get topic from the user among those generated by aAIi.
5. After user selects the topic, use AI to generate a question related to that topic and lecture
6. Get answer from the user.
7. Use AI to validate the answer
8. If validation is created, return it to the user.

Instruction: {instruction}
Let’s think step by step.

"""